@@ -3,14 +3,12 @@ package Alien::Font::Vera;
 use strict;
 use warnings;
 
-our $DATE = '2023-01-29'; # DATE
-our $VERSION = '0.003'; # TRIAL VERSION
-# ABSTRACT: Perl access to Vera ttf font
+our $VERSION = '0.010'; # TRIAL
 
 use File::ShareDir 'dist_dir';
 use File::Spec;
 
-sub get_path { File::Spec->catfile( dist_dir('Alien-Font-Vera') , 'Vera.ttf') }
+sub path { File::Spec->catfile( dist_dir('Alien-Font-Vera') , 'Vera.ttf') }
 
 1;
 
